==> kazehakase_0.4.3.orig.tar.gz: kazehakase-0.4.3.orig/src/kz-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "kz-enum-types.h"
#include "kazehakase.h"
#include "kz-embed.h"
#include "kz-embed-event.h"
#include "kz-gesture.h"
#include "kz-tab-label.h"
#include "kz-icons.h"
#include "kz-prefs-win.h"
#include "kz-sidebar.h"
#include "kz-window.h"
#include "kz-profile.h"
#include "kz-xml.h"
#include "kz-downloader.h"
#include "kz-downloader-group.h"
#include "kz-download-box.h"
#include "kz-feed-info.h"
#include "kz-navi.h"
#include "kz-proxy-menu.h"
#include "kz-proxy-item.h"
#include "kz-favicon.h"
#include "kz-langinfo.h"
#include "kz-thumbnails-view.h"
#include "kz-autoscroller.h"
#include "kz-popup-preview.h"
#include "kz-popup-tablist.h"
#include "kz-statusbar.h"
#include "kz-ext.h"

/* enumerations from "kazehakase.h" */
GType
kz_ui_level_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_UI_LEVEL_INVALID, "KZ_UI_LEVEL_INVALID", "invalid" },
      { KZ_UI_LEVEL_BEGINNER, "KZ_UI_LEVEL_BEGINNER", "beginner" },
      { KZ_UI_LEVEL_MEDIUM, "KZ_UI_LEVEL_MEDIUM", "medium" },
      { KZ_UI_LEVEL_EXPERT, "KZ_UI_LEVEL_EXPERT", "expert" },
      { KZ_UI_LEVEL_CUSTOM, "KZ_UI_LEVEL_CUSTOM", "custom" },
      { KZ_UI_LEVEL_ALL, "KZ_UI_LEVEL_ALL", "all" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzUILevel", values);
  }
  return etype;
}

/* enumerations from "kz-embed.h" */
GType
kz_embed_load_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_EMBED_NORMAL_FLAG, "KZ_EMBED_NORMAL_FLAG", "normal-flag" },
      { KZ_EMBED_SOURCE_FLAG, "KZ_EMBED_SOURCE_FLAG", "source-flag" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedLoadFlag", values);
  }
  return etype;
}
GType
kz_embed_reload_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_RELOAD_NORMAL, "KZ_EMBED_RELOAD_NORMAL", "normal" },
      { KZ_EMBED_RELOAD_BYPASS_CACHE, "KZ_EMBED_RELOAD_BYPASS_CACHE", "bypass-cache" },
      { KZ_EMBED_RELOAD_BYPASS_PROXY, "KZ_EMBED_RELOAD_BYPASS_PROXY", "bypass-proxy" },
      { KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE, "KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE", "bypass-proxy-and-cache" },
      { KZ_EMBED_RELOAD_CHARSET_CHANGE, "KZ_EMBED_RELOAD_CHARSET_CHANGE", "charset-change" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedReloadFlag", values);
  }
  return etype;
}
GType
kz_embed_go_action_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_GO_NONE, "KZ_EMBED_GO_NONE", "none" },
      { KZ_EMBED_GO_BACK, "KZ_EMBED_GO_BACK", "back" },
      { KZ_EMBED_GO_FORWARD, "KZ_EMBED_GO_FORWARD", "forward" },
      { KZ_EMBED_GO_UP, "KZ_EMBED_GO_UP", "up" },
      { KZ_EMBED_GO_INDEX, "KZ_EMBED_GO_INDEX", "index" },
      { KZ_EMBED_GO_CONTENTS, "KZ_EMBED_GO_CONTENTS", "contents" },
      { KZ_EMBED_GO_START, "KZ_EMBED_GO_START", "start" },
      { KZ_EMBED_GO_PREV, "KZ_EMBED_GO_PREV", "prev" },
      { KZ_EMBED_GO_NEXT, "KZ_EMBED_GO_NEXT", "next" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedGoAction", values);
  }
  return etype;
}
GType
kz_embed_nav_link_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_LINK_NEXT, "KZ_EMBED_LINK_NEXT", "next" },
      { KZ_EMBED_LINK_PREV, "KZ_EMBED_LINK_PREV", "prev" },
      { KZ_EMBED_LINK_INDEX, "KZ_EMBED_LINK_INDEX", "index" },
      { KZ_EMBED_LINK_CONTENTS, "KZ_EMBED_LINK_CONTENTS", "contents" },
      { KZ_EMBED_LINK_START, "KZ_EMBED_LINK_START", "start" },
      { KZ_EMBED_LINK_RSS, "KZ_EMBED_LINK_RSS", "rss" },
      { KZ_EMBED_LINK_GUARD, "KZ_EMBED_LINK_GUARD", "guard" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedNavLink", values);
  }
  return etype;
}
GType
kz_embed_copy_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_COPY_NORMAL, "KZ_EMBED_COPY_NORMAL", "normal" },
      { KZ_EMBED_COPY_SOURCE, "KZ_EMBED_COPY_SOURCE", "source" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedCopyType", values);
  }
  return etype;
}

/* enumerations from "kz-embed-event.h" */
GType
kz_embed_event_key_modifier_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_ALT_KEY, "KZ_ALT_KEY", "alt-key" },
      { KZ_CTRL_KEY, "KZ_CTRL_KEY", "ctrl-key" },
      { KZ_SHIFT_KEY, "KZ_SHIFT_KEY", "shift-key" },
      { KZ_META_KEY, "KZ_META_KEY", "meta-key" },
      { KZ_KEY_CODE, "KZ_KEY_CODE", "key-code" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedEventKeyModifier", values);
  }
  return etype;
}
GType
kz_embed_event_context_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_CONTEXT_NONE, "KZ_CONTEXT_NONE", "none" },
      { KZ_CONTEXT_DEFAULT, "KZ_CONTEXT_DEFAULT", "default" },
      { KZ_CONTEXT_LINK, "KZ_CONTEXT_LINK", "link" },
      { KZ_CONTEXT_IMAGE, "KZ_CONTEXT_IMAGE", "image" },
      { KZ_CONTEXT_DOCUMENT, "KZ_CONTEXT_DOCUMENT", "document" },
      { KZ_CONTEXT_INPUT, "KZ_CONTEXT_INPUT", "input" },
      { KZ_CONTEXT_TEXTAREA, "KZ_CONTEXT_TEXTAREA", "textarea" },
      { KZ_CONTEXT_SELECTION, "KZ_CONTEXT_SELECTION", "selection" },
      { KZ_CONTEXT_OTHER, "KZ_CONTEXT_OTHER", "other" },
      { KZ_CONTEXT_XUL, "KZ_CONTEXT_XUL", "xul" },
      { KZ_CONTEXT_FRAME, "KZ_CONTEXT_FRAME", "frame" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedEventContext", values);
  }
  return etype;
}
GType
kz_embed_event_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_EVENT_KEY, "KZ_EMBED_EVENT_KEY", "key" },
      { KZ_EMBED_EVENT_MOUSE, "KZ_EMBED_EVENT_MOUSE", "mouse" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedEventType", values);
  }
  return etype;
}

/* enumerations from "kz-tab-label.h" */
GType
kz_tab_label_state_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_TAB_LABEL_STATE_NORMAL, "KZ_TAB_LABEL_STATE_NORMAL", "state-normal" },
      { KZ_TAB_LABEL_STATE_LOADING, "KZ_TAB_LABEL_STATE_LOADING", "state-loading" },
      { KZ_TAB_LABEL_STATE_LOADED, "KZ_TAB_LABEL_STATE_LOADED", "state-loaded" },
      { KZ_TAB_LABEL_N_STATE, "KZ_TAB_LABEL_N_STATE", "n-state" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzTabLabelState", values);
  }
  return etype;
}

/* enumerations from "kz-prefs-win.h" */
GType
kz_prefs_win_response_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_RESPONSE_UI_LEVEL_BEGINNER, "KZ_RESPONSE_UI_LEVEL_BEGINNER", "beginner" },
      { KZ_RESPONSE_UI_LEVEL_MEDIUM, "KZ_RESPONSE_UI_LEVEL_MEDIUM", "medium" },
      { KZ_RESPONSE_UI_LEVEL_EXPERT, "KZ_RESPONSE_UI_LEVEL_EXPERT", "expert" },
      { KZ_RESPONSE_UI_LEVEL_CUSTOM, "KZ_RESPONSE_UI_LEVEL_CUSTOM", "custom" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzPrefsWinResponse", values);
  }
  return etype;
}

/* enumerations from "kz-xml.h" */
GType
kz_xml_node_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_XML_NODE_INVALID, "KZ_XML_NODE_INVALID", "node-invalid" },
      { KZ_XML_NODE_DOC_ROOT, "KZ_XML_NODE_DOC_ROOT", "node-doc-root" },
      { KZ_XML_NODE_XML_DECL, "KZ_XML_NODE_XML_DECL", "node-xml-decl" },
      { KZ_XML_NODE_DOCTYPE, "KZ_XML_NODE_DOCTYPE", "node-doctype" },
      { KZ_XML_NODE_ELEMENT, "KZ_XML_NODE_ELEMENT", "node-element" },
      { KZ_XML_NODE_TEXT, "KZ_XML_NODE_TEXT", "node-text" },
      { KZ_XML_NODE_COMMENT, "KZ_XML_NODE_COMMENT", "node-comment" },
      { KZ_XML_NODE_PI, "KZ_XML_NODE_PI", "node-pi" },
      { KZ_XML_NODE_CDATA, "KZ_XML_NODE_CDATA", "node-cdata" },
      { KZ_XML_NODE_OTHER, "KZ_XML_NODE_OTHER", "node-other" },
      { KZ_XML_N_NODE_TYPES, "KZ_XML_N_NODE_TYPES", "n-node-types" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzXMLNodeType", values);
  }
  return etype;
}

/* enumerations from "kz-langinfo.h" */
GType
language_group_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { LG_ARABIC, "LG_ARABIC", "arabic" },
      { LG_BALTIC, "LG_BALTIC", "baltic" },
      { LG_CENTRAL_EUROPEAN, "LG_CENTRAL_EUROPEAN", "central-european" },
      { LG_CHINESE, "LG_CHINESE", "chinese" },
      { LG_CYRILLIC, "LG_CYRILLIC", "cyrillic" },
      { LG_GREEK, "LG_GREEK", "greek" },
      { LG_HEBREW, "LG_HEBREW", "hebrew" },
      { LG_INDIAN, "LG_INDIAN", "indian" },
      { LG_JAPANESE, "LG_JAPANESE", "japanese" },
      { LG_KOREAN, "LG_KOREAN", "korean" },
      { LG_TURKISH, "LG_TURKISH", "turkish" },
      { LG_UNICODE, "LG_UNICODE", "unicode" },
      { LG_VIETNAMESE, "LG_VIETNAMESE", "vietnamese" },
      { LG_WESTERN, "LG_WESTERN", "western" },
      { LG_OTHER, "LG_OTHER", "other" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("LanguageGroup", values);
  }
  return etype;
}

/* enumerations from "kz-thumbnails-view.h" */
GType
kz_thumbnails_view_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_THUMBNAILS_VIEW_HORIZONTAL, "KZ_THUMBNAILS_VIEW_HORIZONTAL", "horizontal" },
      { KZ_THUMBNAILS_VIEW_VERTICAL, "KZ_THUMBNAILS_VIEW_VERTICAL", "vertical" },
      { KZ_THUMBNAILS_VIEW_PLANE, "KZ_THUMBNAILS_VIEW_PLANE", "plane" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzThumbnailsViewMode", values);
  }
  return etype;
}

/* Generated data ends here */

==> kazehakase_0.5.2.orig.tar.gz: kazehakase-0.5.2/src/kz-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "kz-enum-types.h"
#include "kazehakase.h"
#include "kz-app.h"
#include "kz-module.h"
#include "kz-module-impl.h"
#include "kz-embed.h"
#include "kz-embed-event.h"
#include "kz-embed-prefs.h"
#include "kz-gesture.h"
#include "kz-tab-label.h"
#include "kz-icons.h"
#include "kz-prefs-win.h"
#include "kz-sidebar.h"
#include "kz-window.h"
#include "kz-profile.h"
#include "kz-xml.h"
#include "kz-downloader.h"
#include "kz-downloader-group.h"
#include "kz-download-box.h"
#include "kz-feed-info.h"
#include "kz-navi.h"
#include "kz-notebook.h"
#include "kz-proxy-menu.h"
#include "kz-proxy-item.h"
#include "kz-favicon.h"
#include "kz-langinfo.h"
#include "kz-thumbnails-view.h"
#include "kz-autoscroller.h"
#include "kz-popup-preview.h"
#include "kz-popup-tablist.h"
#include "kz-search.h"
#include "kz-statusbar.h"
#include "kz-migemo.h"
#include "kz-ext.h"

/* enumerations from "kz-app.h" */
GType
kz_ui_level_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_UI_LEVEL_INVALID, "KZ_UI_LEVEL_INVALID", "invalid" },
      { KZ_UI_LEVEL_BEGINNER, "KZ_UI_LEVEL_BEGINNER", "beginner" },
      { KZ_UI_LEVEL_MEDIUM, "KZ_UI_LEVEL_MEDIUM", "medium" },
      { KZ_UI_LEVEL_EXPERT, "KZ_UI_LEVEL_EXPERT", "expert" },
      { KZ_UI_LEVEL_CUSTOM, "KZ_UI_LEVEL_CUSTOM", "custom" },
      { KZ_UI_LEVEL_ALL, "KZ_UI_LEVEL_ALL", "all" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzUILevel", values);
  }
  return etype;
}

/* enumerations from "kz-embed.h" */
GType
kz_embed_load_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_EMBED_NORMAL_FLAG, "KZ_EMBED_NORMAL_FLAG", "normal-flag" },
      { KZ_EMBED_SOURCE_FLAG, "KZ_EMBED_SOURCE_FLAG", "source-flag" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedLoadFlag", values);
  }
  return etype;
}
GType
kz_embed_reload_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_RELOAD_NORMAL, "KZ_EMBED_RELOAD_NORMAL", "normal" },
      { KZ_EMBED_RELOAD_BYPASS_CACHE, "KZ_EMBED_RELOAD_BYPASS_CACHE", "bypass-cache" },
      { KZ_EMBED_RELOAD_BYPASS_PROXY, "KZ_EMBED_RELOAD_BYPASS_PROXY", "bypass-proxy" },
      { KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE, "KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE", "bypass-proxy-and-cache" },
      { KZ_EMBED_RELOAD_CHARSET_CHANGE, "KZ_EMBED_RELOAD_CHARSET_CHANGE", "charset-change" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedReloadFlag", values);
  }
  return etype;
}
GType
kz_embed_go_action_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_GO_NONE, "KZ_EMBED_GO_NONE", "none" },
      { KZ_EMBED_GO_BACK, "KZ_EMBED_GO_BACK", "back" },
      { KZ_EMBED_GO_FORWARD, "KZ_EMBED_GO_FORWARD", "forward" },
      { KZ_EMBED_GO_UP, "KZ_EMBED_GO_UP", "up" },
      { KZ_EMBED_GO_INDEX, "KZ_EMBED_GO_INDEX", "index" },
      { KZ_EMBED_GO_CONTENTS, "KZ_EMBED_GO_CONTENTS", "contents" },
      { KZ_EMBED_GO_START, "KZ_EMBED_GO_START", "start" },
      { KZ_EMBED_GO_PREV, "KZ_EMBED_GO_PREV", "prev" },
      { KZ_EMBED_GO_NEXT, "KZ_EMBED_GO_NEXT", "next" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedGoAction", values);
  }
  return etype;
}
GType
kz_embed_nav_link_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_LINK_NEXT, "KZ_EMBED_LINK_NEXT", "next" },
      { KZ_EMBED_LINK_PREV, "KZ_EMBED_LINK_PREV", "prev" },
      { KZ_EMBED_LINK_INDEX, "KZ_EMBED_LINK_INDEX", "index" },
      { KZ_EMBED_LINK_CONTENTS, "KZ_EMBED_LINK_CONTENTS", "contents" },
      { KZ_EMBED_LINK_START, "KZ_EMBED_LINK_START", "start" },
      { KZ_EMBED_LINK_RSS, "KZ_EMBED_LINK_RSS", "rss" },
      { KZ_EMBED_LINK_GUARD, "KZ_EMBED_LINK_GUARD", "guard" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedNavLink", values);
  }
  return etype;
}
GType
kz_embed_copy_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_COPY_NORMAL, "KZ_EMBED_COPY_NORMAL", "normal" },
      { KZ_EMBED_COPY_SOURCE, "KZ_EMBED_COPY_SOURCE", "source" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedCopyType", values);
  }
  return etype;
}

/* enumerations from "kz-embed-event.h" */
GType
kz_embed_event_key_modifier_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_ALT_KEY, "KZ_ALT_KEY", "alt-key" },
      { KZ_CTRL_KEY, "KZ_CTRL_KEY", "ctrl-key" },
      { KZ_SHIFT_KEY, "KZ_SHIFT_KEY", "shift-key" },
      { KZ_META_KEY, "KZ_META_KEY", "meta-key" },
      { KZ_KEY_CODE, "KZ_KEY_CODE", "key-code" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedEventKeyModifier", values);
  }
  return etype;
}
GType
kz_embed_event_context_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { KZ_CONTEXT_NONE, "KZ_CONTEXT_NONE", "none" },
      { KZ_CONTEXT_DEFAULT, "KZ_CONTEXT_DEFAULT", "default" },
      { KZ_CONTEXT_LINK, "KZ_CONTEXT_LINK", "link" },
      { KZ_CONTEXT_IMAGE, "KZ_CONTEXT_IMAGE", "image" },
      { KZ_CONTEXT_DOCUMENT, "KZ_CONTEXT_DOCUMENT", "document" },
      { KZ_CONTEXT_INPUT, "KZ_CONTEXT_INPUT", "input" },
      { KZ_CONTEXT_TEXTAREA, "KZ_CONTEXT_TEXTAREA", "textarea" },
      { KZ_CONTEXT_SELECTION, "KZ_CONTEXT_SELECTION", "selection" },
      { KZ_CONTEXT_OTHER, "KZ_CONTEXT_OTHER", "other" },
      { KZ_CONTEXT_XUL, "KZ_CONTEXT_XUL", "xul" },
      { KZ_CONTEXT_FRAME, "KZ_CONTEXT_FRAME", "frame" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("KzEmbedEventContext", values);
  }
  return etype;
}
GType
kz_embed_event_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_EMBED_EVENT_KEY, "KZ_EMBED_EVENT_KEY", "key" },
      { KZ_EMBED_EVENT_MOUSE, "KZ_EMBED_EVENT_MOUSE", "mouse" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzEmbedEventType", values);
  }
  return etype;
}

/* enumerations from "kz-tab-label.h" */
GType
kz_tab_label_state_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_TAB_LABEL_STATE_NORMAL, "KZ_TAB_LABEL_STATE_NORMAL", "state-normal" },
      { KZ_TAB_LABEL_STATE_LOADING, "KZ_TAB_LABEL_STATE_LOADING", "state-loading" },
      { KZ_TAB_LABEL_STATE_LOADED, "KZ_TAB_LABEL_STATE_LOADED", "state-loaded" },
      { KZ_TAB_LABEL_N_STATE, "KZ_TAB_LABEL_N_STATE", "n-state" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzTabLabelState", values);
  }
  return etype;
}

/* enumerations from "kz-prefs-win.h" */
GType
kz_prefs_win_response_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_RESPONSE_UI_LEVEL_BEGINNER, "KZ_RESPONSE_UI_LEVEL_BEGINNER", "beginner" },
      { KZ_RESPONSE_UI_LEVEL_MEDIUM, "KZ_RESPONSE_UI_LEVEL_MEDIUM", "medium" },
      { KZ_RESPONSE_UI_LEVEL_EXPERT, "KZ_RESPONSE_UI_LEVEL_EXPERT", "expert" },
      { KZ_RESPONSE_UI_LEVEL_CUSTOM, "KZ_RESPONSE_UI_LEVEL_CUSTOM", "custom" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzPrefsWinResponse", values);
  }
  return etype;
}

/* enumerations from "kz-xml.h" */
GType
kz_xml_node_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_XML_NODE_INVALID, "KZ_XML_NODE_INVALID", "node-invalid" },
      { KZ_XML_NODE_DOC_ROOT, "KZ_XML_NODE_DOC_ROOT", "node-doc-root" },
      { KZ_XML_NODE_XML_DECL, "KZ_XML_NODE_XML_DECL", "node-xml-decl" },
      { KZ_XML_NODE_DOCTYPE, "KZ_XML_NODE_DOCTYPE", "node-doctype" },
      { KZ_XML_NODE_ELEMENT, "KZ_XML_NODE_ELEMENT", "node-element" },
      { KZ_XML_NODE_TEXT, "KZ_XML_NODE_TEXT", "node-text" },
      { KZ_XML_NODE_COMMENT, "KZ_XML_NODE_COMMENT", "node-comment" },
      { KZ_XML_NODE_PI, "KZ_XML_NODE_PI", "node-pi" },
      { KZ_XML_NODE_CDATA, "KZ_XML_NODE_CDATA", "node-cdata" },
      { KZ_XML_NODE_OTHER, "KZ_XML_NODE_OTHER", "node-other" },
      { KZ_XML_N_NODE_TYPES, "KZ_XML_N_NODE_TYPES", "n-node-types" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzXMLNodeType", values);
  }
  return etype;
}

/* enumerations from "kz-notebook.h" */
GType
kz_notebook_close_condition_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_NOTEBOOK_CLOSE_INACTIVE, "KZ_NOTEBOOK_CLOSE_INACTIVE", "inactive" },
      { KZ_NOTEBOOK_CLOSE_BACKWARD, "KZ_NOTEBOOK_CLOSE_BACKWARD", "backward" },
      { KZ_NOTEBOOK_CLOSE_FORWARD, "KZ_NOTEBOOK_CLOSE_FORWARD", "forward" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzNotebookCloseCondition", values);
  }
  return etype;
}

/* enumerations from "kz-langinfo.h" */
GType
language_group_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { LG_ARABIC, "LG_ARABIC", "arabic" },
      { LG_BALTIC, "LG_BALTIC", "baltic" },
      { LG_CENTRAL_EUROPEAN, "LG_CENTRAL_EUROPEAN", "central-european" },
      { LG_CHINESE, "LG_CHINESE", "chinese" },
      { LG_CYRILLIC, "LG_CYRILLIC", "cyrillic" },
      { LG_GREEK, "LG_GREEK", "greek" },
      { LG_HEBREW, "LG_HEBREW", "hebrew" },
      { LG_INDIAN, "LG_INDIAN", "indian" },
      { LG_JAPANESE, "LG_JAPANESE", "japanese" },
      { LG_KOREAN, "LG_KOREAN", "korean" },
      { LG_TURKISH, "LG_TURKISH", "turkish" },
      { LG_UNICODE, "LG_UNICODE", "unicode" },
      { LG_VIETNAMESE, "LG_VIETNAMESE", "vietnamese" },
      { LG_WESTERN, "LG_WESTERN", "western" },
      { LG_OTHER, "LG_OTHER", "other" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("LanguageGroup", values);
  }
  return etype;
}

/* enumerations from "kz-thumbnails-view.h" */
GType
kz_thumbnails_view_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { KZ_THUMBNAILS_VIEW_HORIZONTAL, "KZ_THUMBNAILS_VIEW_HORIZONTAL", "horizontal" },
      { KZ_THUMBNAILS_VIEW_VERTICAL, "KZ_THUMBNAILS_VIEW_VERTICAL", "vertical" },
      { KZ_THUMBNAILS_VIEW_PLANE, "KZ_THUMBNAILS_VIEW_PLANE", "plane" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("KzThumbnailsViewMode", values);
  }
  return etype;
}

/* Generated data ends here */
